class LSystem:
    def __init__(self, variables, constants, axiom, rules, iterations=0):
        self.variables = variables
        self.constants = constants
        self.axiom = axiom
        self.rules = rules
        self.system = [self.axiom]
        for i in range(iterations):
            self.iterate()

    def __repr__(self):
        return str(self.system)

    def iterate(self, iterations=1):
        for i in range(iterations):
            nxt = self.system[-1]
            rep={} # replacements
            count=1;
            for var in self.rules.keys():
                repstr = str(chr(count))
                nxt=repstr.join( nxt.split(var) )
                rep[repstr] = var
                count=count+1
            for var in rep.keys():
                nxt = self.rules[rep[var]].join(nxt.split(var))

            self.system.append(nxt)




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="LindenmayerSystem", # Replace with your own username
    version="1.0.0",
    author="Subimal Deb",
    author_email="subimal.deb@gmail.com",
    description="A pure python module for generating iterations from the L-System or Lindenmayer system.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/subimal/LSystem",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
